@@ -2,6 +2,9 @@ import logging
 
 import click
 import sys
+
+from typing import List
+
 from cli.models import Severity
 from cli.config import config
 from cli import code_scanner, __version__
@@ -12,6 +15,7 @@ from cli.user_settings.configuration_manager import ConfigurationManager
 from cli.user_settings.user_settings_commands import set_credentials, add_exclusions
 from cli.auth.auth_command import authenticate
 from cli.utils import scan_utils
+from cyclient.scan_config.scan_config_creator import create_scan_client
 
 CONTEXT = dict()
 ISSUE_DETECTED_STATUS_CODE = 1
@@ -68,8 +72,26 @@ NO_ISSUES_STATUS_CODE = 0
               help='Show only violations at the specified level or higher (supported for SCA scan type only).',
               type=click.Choice([e.name for e in Severity]),
               required=False)
+@click.option('--sca-scan',
+              default=None,
+              help="Specify the sca scan you wish to execute (package-vulnerabilities/license-compliance), the default is both",
+              multiple=True,
+              type=click.Choice(config['scans']['supported_sca_scans']))
+@click.option('--monitor',
+              is_flag=True,
+              default=False,
+              help="When specified, the scan results will be recorded in the knowledge graph. Please note that when working in 'monitor' mode, the knowledge graph will not be updated as a result of SCM events (Push, Repo creation).(supported for SCA scan type only).",
+              type=bool,
+              required=False)
+@click.option('--report',
+              is_flag=True,
+              default=False,
+              help="When specified, a violations report will be generated. A URL link to the report will be printed as an output to the command execution",
+              type=bool,
+              required=False)
 @click.pass_context
-def code_scan(context: click.Context, scan_type, client_id, secret, show_secret, soft_fail, output, severity_threshold):
+def code_scan(context: click.Context, scan_type, client_id, secret, show_secret, soft_fail, output, severity_threshold,
+              sca_scan: List[str], monitor, report):
     """ Scan content for secrets/IaC/sca/SAST violations, You need to specify which scan type: ci/commit_history/path/repository/etc """
     if show_secret:
         context.obj["show_secret"] = show_secret
@@ -85,6 +107,9 @@ def code_scan(context: click.Context, scan_type, client_id, secret, show_secret,
     context.obj["output"] = output
     context.obj["client"] = get_cycode_client(client_id, secret)
     context.obj["severity_threshold"] = severity_threshold
+    context.obj["monitor"] = monitor
+    context.obj["report"] = report
+    _sca_scan_to_context(context, sca_scan)
 
     return 1
 
@@ -129,7 +154,7 @@ def get_cycode_client(client_id, client_secret):
         if not client_secret:
             raise click.ClickException("Cycode client secret is needed.")
 
-    return ScanClient(client_secret=client_secret, client_id=client_id)
+    return create_scan_client(client_id, client_secret)
 
 
 def _get_configured_credentials():
@@ -141,5 +166,10 @@ def _should_fail_scan(context: click.Context):
     return scan_utils.is_scan_failed(context)
 
 
+def _sca_scan_to_context(context: click.Context, sca_scan_user_selected: List[str]):
+    for sca_scan_option_selected in sca_scan_user_selected:
+        context.obj[sca_scan_option_selected] = True
+
+
 if __name__ == '__main__':
     main_cli()
