@@ -6,6 +6,11 @@ from cli.models import DocumentDetections
 
 class BasePrinter(ABC):
 
+    context: click.Context
+
+    def __init__(self, context: click.Context):
+        self.context = context
+
     @abstractmethod
-    def print_results(self, context: click.Context, results: List[DocumentDetections]):
+    def print_results(self, results: List[DocumentDetections]):
         pass
